{ pkgs, ... }:
let
  inherit (pkgs.lib) optionals mkForce;
  inherit (pkgs.stdenv) isLinux isDarwin;
in
{
  imports = [
    ./btop
    ./direnv
    ./powerline
    ./readline
    ./hyprland
    ./waybar
  ];

  reichardnix = {
    programs.nvim.enable = true;
    programs.ghostty.enable = true;
    programs.git.enable = true;
  };

  # Home Manager Config
  home.stateVersion = "24.11";
  home.username = "evanreichard";
  home.homeDirectory = mkForce (if isLinux then "/home/evanreichard" else "/Users/evanreichard");
  programs.home-manager.enable = true;

  # Global Packages
  home.packages = with pkgs; [
    # --- Android Dev ---
    android-tools

    # --- AWS ---
    cw
    awscli2
    ssm-session-manager-plugin

    # --- Kubernetes ---
    kubectl
    kubernetes-helm

    # --- Uncategorized ---
    imagemagick
    mosh
    python311
    texliveSmall # Pandoc PDF Dep
    google-cloud-sdk
    tldr
  ]
  ++ optionals isLinux [
    ghostty
    hyprpaper
    firefox
  ]
  ++ optionals isDarwin [ ];

  # Misc Programs
  programs.jq.enable = true;
  programs.k9s.enable = true;
  programs.pandoc.enable = true;

  # Enable Flakes & Commands
  nix = {
    package = mkForce pkgs.nix;
    settings = {
      experimental-features = "nix-command flakes";
    };
  };

  # SQLite Configuration
  home.file.".sqliterc".text = ''
    .headers on
    .mode column
  '';

  # Darwin Spotlight Indexing Hack
  disabledModules = [ "targets/darwin/linkapps.nix" ];
}
